@@ -55,6 +55,8 @@ static store_t store[] = {
   { "active_location",  STORE_INT,    OFFSET(active_location) },
   { "mmpoi_use_radius", STORE_BOOL,   OFFSET(mmpoi_use_radius) },
   { "mmpoi_radius",     STORE_FLOAT,  OFFSET(mmpoi_radius) },
+  { "mmpoi_ign_found",  STORE_BOOL,   OFFSET(mmpoi_dont_export_found) },
+  { "mmpoi_ign_disabl", STORE_BOOL,   OFFSET(mmpoi_dont_export_disabled) },
   { "use_gps",          STORE_BOOL,   OFFSET(use_gps) },
   { "imperial",         STORE_BOOL,   OFFSET(imperial) },
   { "compass_locked",   STORE_BOOL,   OFFSET(compass_locked) },
