@@ -127,6 +127,8 @@ typedef struct {
   char *mmpoi_path;           /* path to save poi to */
   float mmpoi_radius;
   gboolean mmpoi_use_radius;
+  gboolean mmpoi_dont_export_found;
+  gboolean mmpoi_dont_export_disabled;
 
   char *garmin_path;           /* path to save garmin data to */
   gboolean garmin_ign_found;
