@@ -141,6 +141,12 @@ static gpx_t *export_list_create(appdata_t *appdata, int *mode) {
     printf("gpxlist display, exporting all caches\n");
     gpx_t *lgpx = appdata->gpx;
     while(lgpx) {
+      /* make sure notes are imported */
+      if(!lgpx->notes_loaded) {
+	notes_load_all(appdata, lgpx);
+	lgpx->notes_loaded = TRUE;
+      }
+
       cache_t *cache = lgpx->cache;
       while(cache) { chain_cache(gpx, cache); cache = cache->next; }
       lgpx = lgpx->next;
@@ -169,13 +175,24 @@ static int export_list_count(appdata_t *appdata, gpx_t *gpx) {
 
   cache_t *cache = gpx->cache;
   while(cache) {
-    if(appdata->mmpoi_use_radius && !isnan(appdata->mmpoi_radius)) {
-      /* count all caches within given radius around current position */
-      if(gpx_pos_get_distance(*refpos, gpx_cache_pos(cache), 0) < 
-	 appdata->mmpoi_radius)
-	cnt++;
-    } else
-      cnt++;
+    /* no disabled/archived if requested */
+    if(!(appdata->mmpoi_dont_export_disabled && 
+	 (!cache->available || cache->archived))) {
+
+      /* no found if requested */
+      if(!(appdata->mmpoi_dont_export_found && 
+	   cache->notes && cache->notes->found)) {
+	   
+	if(appdata->mmpoi_use_radius && !isnan(appdata->mmpoi_radius)) {
+	  /* count all caches within given radius around current position */
+	  if(gpx_pos_get_distance(*refpos, gpx_cache_pos(cache), 0) < 
+	     appdata->mmpoi_radius)
+	    cnt++;
+	} else
+	  cnt++;
+      }
+      
+    }
 
     cache = cache->next;
   }
@@ -184,6 +201,8 @@ static int export_list_count(appdata_t *appdata, gpx_t *gpx) {
 
 typedef struct {
   GtkWidget *use_radius;
+  GtkWidget *no_found;
+  GtkWidget *no_disabled;
   GtkWidget *entry;
   GtkWidget *info_label;
   GtkWidget *dialog;
@@ -242,6 +261,12 @@ static void export_update(GtkWidget *widget, gpointer data) {
     context->appdata->mmpoi_use_radius = FALSE;
   }
 
+  context->appdata->mmpoi_dont_export_found = 
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context->no_found));
+
+  context->appdata->mmpoi_dont_export_disabled = 
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context->no_disabled));
+
   export_list_update(context);
 }
 
@@ -356,16 +381,15 @@ void mmpoi_export(appdata_t *appdata) {
   GtkWidget *vbox = gtk_vbox_new(FALSE,0);
 
   /* ------------------ radius limit gui ------------------ */
-  gtk_box_pack_start_defaults(GTK_BOX(vbox),
-		      context.use_radius = gtk_check_button_new_with_label(
-		   _("Limit export radius")));
-
+			      
   GtkWidget *label, *hbox = gtk_hbox_new(FALSE,2);
-  gtk_box_pack_start_defaults(GTK_BOX(hbox), label = gtk_label_new(_("Radius:")));
-  gtk_box_pack_start_defaults(GTK_BOX(hbox), 
-		      context.entry = dist_entry_new(appdata->mmpoi_radius, appdata->imperial));
-  gtk_box_pack_start_defaults(GTK_BOX(vbox),hbox);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
+  context.use_radius = gtk_check_button_new_with_label(
+	       _("Limit export radius to:"));
+  context.entry = dist_entry_new(appdata->mmpoi_radius, appdata->imperial);
+
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context.use_radius);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context.entry);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox), hbox);
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context.use_radius), 
 			       appdata->mmpoi_use_radius);
@@ -377,6 +401,34 @@ void mmpoi_export(appdata_t *appdata) {
   g_signal_connect(G_OBJECT(context.entry), "changed",
 		   G_CALLBACK(export_radius_modified), (gpointer)&context);
 
+  /* ------------------ don't export found/disabled/archived -------------- */
+
+  hbox = gtk_hbox_new(FALSE,2); 
+
+  label = gtk_label_new(_("Don't export"));
+  gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
+  context.no_found = gtk_check_button_new_with_label(_("found"));
+  context.no_disabled = gtk_check_button_new_with_label(_("disabled/archived"));
+
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context.no_found), 
+			       appdata->mmpoi_dont_export_found);
+
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context.no_disabled), 
+			       appdata->mmpoi_dont_export_disabled);
+
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), label);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context.no_found);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context.no_disabled);
+
+  gtk_signal_connect (GTK_OBJECT(context.no_found), "clicked",
+		      GTK_SIGNAL_FUNC(export_update), (gpointer)&context);
+  gtk_signal_connect (GTK_OBJECT(context.no_disabled), "clicked",
+		      GTK_SIGNAL_FUNC(export_update), (gpointer)&context);
+
+  gtk_box_pack_start_defaults(GTK_BOX(vbox),hbox);
+
+  /* ------------------ info text -------------- */
+
   context.info_label = gtk_label_new("");
   gtk_label_set_line_wrap_mode(GTK_LABEL(context.info_label), PANGO_WRAP_WORD);
   gtk_label_set_line_wrap(GTK_LABEL(context.info_label), TRUE);
@@ -396,7 +448,6 @@ void mmpoi_export(appdata_t *appdata) {
   /* ------------------ path/file ------------------ */
   gtk_box_pack_start_defaults(GTK_BOX(vbox), gtk_hseparator_new());
 
-  /* xyz */
   hbox = gtk_hbox_new(FALSE, 0);
   label = gtk_label_new(_("Export to:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE,0);
@@ -546,16 +597,26 @@ void mmpoi_export(appdata_t *appdata) {
       
       while(cache && !cancelled) {
 	
-	if(appdata->mmpoi_use_radius && !isnan(appdata->mmpoi_radius)) {
-	  /* count all caches within given radius around current position */
-	  if(gpx_pos_get_distance(*refpos, gpx_cache_pos(cache), 0) < 
-	     appdata->mmpoi_radius) {
-	    printf("%d exporting %s\n", id, cache->id);
-	    cache_export(db, id++, cache);
+	/* no disabled/archived if requested */
+	if(!(appdata->mmpoi_dont_export_disabled && 
+	     (!cache->available || cache->archived))) {
+	  
+	  /* no found if requested */
+	  if(!(appdata->mmpoi_dont_export_found && 
+	       cache->notes && cache->notes->found)) {
+
+	    if(appdata->mmpoi_use_radius && !isnan(appdata->mmpoi_radius)) {
+	      /* count all caches within given radius around current position */
+	      if(gpx_pos_get_distance(*refpos, gpx_cache_pos(cache), 0) < 
+		 appdata->mmpoi_radius) {
+		printf("%d exporting %s\n", id, cache->id);
+		cache_export(db, id++, cache);
+	      }
+	    } else {
+	      printf("%d exporting %s\n", id, cache->id);
+	      cache_export(db, id++, cache);
+	    }
 	  }
-	} else {
-	  printf("%d exporting %s\n", id, cache->id);
-	  cache_export(db, id++, cache);
 	}
 	cache = cache->next;
 	
